# -*- coding: utf-8 -*-

from __future__ import absolute_import, division, print_function


class Service(object):
    SPOROPAY = "sporopay"
    ECARD = "ecard"
    EPLATBY = "eplatby"
    TATRAPAY = "tatrapay"
    CARDPAY = "cardpay"
    PAYPAL = "paypal"
    GPWEBPAY = "gpwebpay"
    ITERMINAL = "iterminal"
